/*****************************************************************************
* FILENAME
*   mcbsp1.c
*
* DESCRIPTION
*   Initialization, read and write of McBSP1 for communication with 
*   Audio Daughter Card.
*
*  Rev 1.00   R.Sikora
*
*----------------------------------------------------------------------------
*  HISTORY
*  Rev 1.00  3 January 2002. Created by R.Sikora. Based on cnfdsp_nohost1.c
*            While loops changed to do-while to save code.   
*            For consistent coding, if (temp == 0) changed to if ( 0 == temp)
*
*****************************************************************************/

#include <stdio.h>
#include <c6x.h>
#include "c6211dsk.h"
#include "mcbsp1.h"


/*-------------------------------------------------------------------------*/
/* mcbsp1_init()                                                           */
/*-------------------------------------------------------------------------*/
/*                                                                         */
/* Used to initialize McBSP1. Uses 16-bit data size.                       */
/* Note: if this loop does not terminate properly, program execution       */
/*       could hang.                                                       */
/*                                                                         */
/*-------------------------------------------------------------------------*/

void mcbsp1_init(void)
{

    *(unsigned volatile int *)McBSP1_SPCR = 0;		   /*  reset serial port                         */
    *(unsigned volatile int *)McBSP1_PCR = 0x000C;     /*  set pin control reg.;                     */
    *(unsigned volatile int *)McBSP1_RCR = 0x80400040; /*  0bit delay,set rx control reg. one 16 bit data/frame */
    *(unsigned volatile int *)McBSP1_XCR = 0x80400040; /*  0bit delay, set tx control reg. one 16 bit data/frame */
    *(unsigned volatile int *)McBSP1_DXR = 0;		   /* write first word */
    *(unsigned volatile int *)McBSP1_SPCR = 0x10001;   /*  setup SP control reg., take out of reset, w RJUST=0;                    */

}


/*-------------------------------------------------------------------------*/
/* mcbsp1_write()                                                          */
/*-------------------------------------------------------------------------*/
/*                                                                         */
/* Used to write a 16-bit value to McBSP1.                                 */
/* Note: if this loop does not terminate properly, program execution       */
/*       could hang.                                                       */
/*                                                                         */
/*-------------------------------------------------------------------------*/

void mcbsp1_write(int out_data)
{
  int temp;
  
  do 
  {
    temp = *(unsigned volatile int *)McBSP1_SPCR & 0x20000;
  
  } while ( 0 == temp);  /* Wait for previous transmission to finish */
  
  *(unsigned volatile int *)McBSP1_DXR = out_data;
}

/*-------------------------------------------------------------------------*/
/* mcbsp1_read()                                                           */
/*-------------------------------------------------------------------------*/
/*                                                                         */
/* Used to read a 16-bit value from McBSP1.                                */
/* Note: if this loop does not terminate properly, program execution       */
/*       could hang.                                                       */
/*                                                                         */
/*-------------------------------------------------------------------------*/

int mcbsp1_read()
{
  int temp;
  
  do 
  {
    temp = *(unsigned volatile int *)McBSP1_SPCR & 0x2;
  
  } while ( 0 == temp); /* Wait for data to be received */
  
  temp = *(unsigned volatile int *)McBSP1_DRR;
  
  return temp;
}


/*-------------------------------------------------------------------------*/
/* End of mcbsp1.c                                                         */
/*-------------------------------------------------------------------------*/
